=====================
Logen Trace
=====================

Python 사용자를 위한 '로젠 택배' 배송완료 확인 모듈입니다.
간단하게 송장번호를 목록으로 입력받아, 배송완료 여부와 완료시간을 알려줍니다.

* 이용 중 발생한 문제에 대해 책임지지 않습니다.
* 최초 작성은 `핑크퐁 북스토어 <https://store.pinkfong.com>`_ 에서 쓰기 위해 만들었습니다.

설치
=======

.. code-block:: shell

    pip install logen-trace


사용법
=======

배송 완료 확인
--------------

송장번호를 넣고 배송이 완료 되었는지 확인합니다.

.. code-block:: python


    from logen import Logen

    # 로젠 택배에서 발급 받은 아이디와 암호가 필요합니다.(별도 연락)
    # 테스트용 아이디와 암호 제공되지 않고 있습니다.
    logen = Logen('{ 아이디 }', '{ 비밀번호 }')

    invoices = ['{ 송장번호1 }', '{ 송장번호2 }', '{ 송장번호3 }', '{ .... }']
    res = logen.trace(invoices)

    print res

    # [
    #    {
    #        'invoice': '{ 배송완료된 송장번호 }',
    #        'datetime': '{ 배송완료된 시간(datetime) }'  # 서울 타임존이 적용 되어있습니다.
    #    },
    #    ....
    # ]




* 송장번호 외의 정보로 정보 확인 등의 추가 기능은 기여 바랍니다.
